@@ -38,7 +38,7 @@ def create_credential_resolver(session):
     credentials.
 
     """
-    profile_name = session.profile or 'default'
+    profile_name = session.get_config_variable('profile') or 'default'
     credential_file = session.get_config_variable('credentials_file')
     config_file = session.get_config_variable('config_file')
     metadata_timeout = session.get_config_variable('metadata_service_timeout')
